@@ -89,7 +89,7 @@ tide_height_data_station <- function(data, harmonics) {
   data <- plyr::adply(.data = data, .margins = 1, .fun = tide_height_data_datetime,
                       h = harmonics)
   if (harmonics$Station$Units %in% c("feet", "ft"))
-    data %<>% dplyr::mutate_(TideHeight = ~ft2m(TideHeight))
+    data$TideHeight %<>% ft2m()
   data
 }
 
@@ -112,7 +112,7 @@ tide_height_data <- function(data, harmonics = rtide::harmonics) {
     stop("data already has 'TideHeight' column", call. = FALSE)
 
   tz <- lubridate::tz(data$DateTime)
-  data %<>% dplyr::mutate_(DateTime = ~lubridate::with_tz(DateTime, tzone = "UTC"))
+  data$DateTime %<>% lubridate::with_tz(tzone = "UTC")
 
   years <- range(lubridate::year(data$DateTime), na.rm = TRUE)
   if (!all(years %in% years_tide_harmonics(harmonics)))
@@ -120,10 +120,9 @@ tide_height_data <- function(data, harmonics = rtide::harmonics) {
 
   data %<>% plyr::ddply(.variables = c("Station"), tide_height_data_station, harmonics = harmonics)
 
-  data %<>% dplyr::mutate_(DateTime = ~lubridate::with_tz(DateTime, tzone = tz))
-  data %<>% dplyr::arrange_(~Station, ~DateTime)
-  data %<>% dplyr::as.tbl()
-  data
+  data$DateTime %<>% lubridate::with_tz(tzone = tz)
+  data <- data[order(data$Station, data$DateTime),]
+  tibble::as_tibble(data)
 }
 
 #' Tide Height
